#
# spec file for package python3-espressomd
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2014 Christoph Junghans
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define mpi_implem openmpi2
%ifarch ppc64
%define mpi_implem openmpi
%endif
%if  0%{?sle_version} == 120300 && 0%{?is_opensuse}
%define mpi_implem openmpi
%endif
%if 0%{?sle_version} == 120400 && !0%{?is_opensuse}
%define mpi_implem openmpi
%endif

%define pkgname espresso
%define modname %{pkgname}md
%define sonum 4
Name:           python3-%{modname}
Version:        4.0.1
Release:        bp153.1.17
Summary:        Parallel simulation software for soft matter research
License:        GPL-3.0-or-later
Group:          Productivity/Scientific/Chemistry
URL:            http://espressomd.org
Source:         https://github.com/%{modname}/%{pkgname}/releases/download/%{version}/%{pkgname}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  fftw3-devel
BuildRequires:  gcc-c++
# Currently libboost_mpi-devel and hdf5 use different mpi versions
# BuildRequires:  hdf5-devel
BuildRequires:  gsl-devel
BuildRequires:  %{mpi_implem}-devel
BuildRequires:  python3-Cython
BuildRequires:  python3-devel
BuildRequires:  python3-numpy-devel
%if 0%{?suse_version} > 1325
BuildRequires:  libboost_filesystem-devel
BuildRequires:  libboost_mpi-devel
BuildRequires:  libboost_system-devel
BuildRequires:  libboost_test-devel
%else
BuildRequires:  boost-devel
%endif

%description
ESPResSo is a highly versatile software package for performing and analyzing
scientific Molecular Dynamics many-particle simulations of coarse-grained
atomistic or bead-spring models as they are used in soft-matter research in
physics, chemistry and molecular biology. It can be used to simulate systems
such as polymers, liquid crystals, colloids, ferrofluids and biological
systems, for example DNA and lipid membranes.

%package -n libEspresso%{sonum}
Summary:        Shared libraries for ESPResSo
Group:          System/Libraries

%description -n libEspresso%{sonum}
This package provides shared libraries for ESPResSo.

%prep
%setup -q -n %{pkgname}-%{version}

%build
source %{_libdir}/mpi/gcc/%{mpi_implem}/bin/mpivars.sh

# overwrite .so linker flags on SUSE distros: drop --no-undefined
# we don't install {i,}pypresso scripts as they aren't needed when installing in /usr
%cmake \
  '-DCMAKE_SHARED_LINKER_FLAGS=-Wl,--as-needed -Wl,-z,now' \
  -DLIBDIR=%{_lib} \
  -DPYTHON_EXECUTABLE=%{_bindir}/python3 \
  -DINSTALL_PYPRESSO=OFF

make %{?_smp_mflags}

%install
make -C build install DESTDIR=%{buildroot}
find %{buildroot}%{_prefix} -name "*.so" -exec chmod +x {} \;
find %{buildroot}%{_prefix} -name "gen_pxiconfig" -exec chmod +x {} \;
# no devel package
rm -f %{buildroot}%{_libdir}/lib*.so

%check
# https://github.com/espressomd/espresso/issues/2468
%ifarch ppc64 ppc64le
%global testargs ARGS='-E npt'
%endif
# https://github.com/espressomd/espresso/issues/2469
%ifarch aarch64
%global testargs ARGS='-E analyze_gyration_tensor'
%endif

LD_LIBRARY_PATH='%{buildroot}/%{_libdir}::%{_libdir}/mpi/gcc/%{mpi_implem}/%{_lib}' make -C build check CTEST_OUTPUT_ON_FAILURE=1 %{?testargs:%{testargs}}

%post -n libEspresso%{sonum} -p /sbin/ldconfig
%postun -n libEspresso%{sonum} -p /sbin/ldconfig

%files
%license COPYING
%doc README AUTHORS NEWS ChangeLog
%{python3_sitearch}/espressomd

%files -n libEspresso%{sonum}
%license COPYING
%{_libdir}/libEspressoCore.so.%{sonum}
%{_libdir}/libActor.so.%{sonum}
%{_libdir}/libImmersedBoundary.so.%{sonum}
%{_libdir}/libObjectInFluid.so.%{sonum}
%{_libdir}/libAccumulators.so.%{sonum}
%{_libdir}/libConstraints.so.%{sonum}
%{_libdir}/libEspressoConfig.so.%{sonum}
%{_libdir}/libEspressoScriptInterface.so.%{sonum}
%{_libdir}/libObservables.so.%{sonum}
%{_libdir}/libShapes.so.%{sonum}
%{_libdir}/libVirtualSites.so.%{sonum}
%{_libdir}/libcluster_analysis.so.%{sonum}

%changelog
* Fri Jan 25 2019 Christoph Junghans <junghans@votca.org>
- Version bump to 4.0.1
  * Many small bugfixes
- Drop 2255.patch, 2259.patch and 2265.patch - merged upstream
* Fri Sep 28 2018 Christoph Junghans <junghans@votca.org>
- added change from request #639007
  - rename package to python3-espressomd
  - install COPYING for all packages
  - change license to GPL-3.0-or-later
  - added sonum define
* Fri Sep  7 2018 junghans@votca.org
- Version bump to 4.0.0
- Rename pacakge to python-espressomd
- Dropped 1830.patch - merged upstream
- Dropped doc package - under rework in 4.0.0
- New features:
  - Reaction ensemble methods for the modelling of chemical reactions, including constant pH and Wang-Landau schemes.
  - Polarisable particles via the Drude-oscillator scheme.
  - Steepest-descent energy minimization scheme.
  - Methods for active particles (swimmer_reaction, dipolar swimmers).
  - GPU-accelerated P3M method for electrostatic interactions.
  - GPU-accelerated direct summation and Barnes-Hutt schemes for dipolar interactions under open boundary conditions.
  - Support for the electrostatic and magnetostatics method provided by the ScaFaCoS library.
  - Immersed boundary method for soft immersed objects in an LB fluid.
  - Virtual sites acting as inertialess tracers in an LB fluid usable as part of the immersed boundary method or independently.
  - New bonded quartic and Coulomb interactions.
  - Possibility to tune the skin parameter.
  - Support for saving to the h5md file format for molecular dynamics data.
  - Connection to the MD Analysis Python package.
  - A rotate_system command was added, which rotates the particle positions around the system’s center of mass.
- Added 2255.patch to fix numpy issue on i586
- Added 2259.patch to fix numpy issue on big-endian platforms
- Added 2265.patch to fix test on i586
* Mon Feb 12 2018 junghans@votca.org
- add 1830.patch to fix install
- update version 3.3.1+git20180203.f74064d
  * many many small fixes
  * support for newer cython
* Wed Oct 25 2017 junghans@votca.org
- adapt to new openlmi package - source mpivars.h during build
* Wed Feb  1 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Thu Sep 29 2016 jengelh@inai.de
- RPM group fixup
* Wed Aug  3 2016 junghans@votca.org
- switched to cmake build-system
- build python module
- dropped header as they are for internal use only
- dropped pkg-config files as nothing depends on libs yet
- update version 3.3.1+git20160803.6ed0518.tar.gz
  * overhaul of buildsystem
  * many many small fixes
* Sun Jun 26 2016 i@marguerite.su
- fix boo#985147
  * there's a commit that removed redefinition of malloc and realloc
    which fixed build for gcc 6. but it's too hard to cherry pick, so
    update to the latest git version is a good idea
- there's no --without-mpi option left in configure.ac, so "-openmpi"
  sub-package is meaningless now (everything has openmpi support)
  and since there's no two main packages any more, "-common" sub-package
  is also meaningless now (and it doesn't contains data), merged.
- add sub-package: "-devel", "libEspresso0", "libEspressoTcl0"
- add generate_headers.rb to gather those .hpp that're really used
  into "-devel" sub-package
- create pkgconfig files
- add some texlive BuildRequires to build pdf documentation.
- update version 3.3.1+git20160622.6aa229c:
  * added edge statistics for meshes used by object-in-fluid
  * added pos_folded property
  * Adapted simple LB tests to current interface.
  * system.part.writevtk()
  * redesigned exclusions and added slice input
  * Scafacos: Add long range energy to correct place in energy data structure
  * Correction to scafacos energy calculation: Check cutoff in near field contrib
  * Scafacos: Sort out conditional compilation and cython includes
  * Scafacos: methods shared between electrostatics and dipolar calculations
* Sun Nov  8 2015 p.drouand@gmail.com
- Update to version 3.3.1
  * A lot of changes; please read the NEWS file
* Tue Aug 12 2014 junghans@votca.org
- version bumped to 3.3.0
- Highlights of this release include:
  - Calculation of the electrokinetic equations via the ELECTROKINETICS feature,
  - the Shan/Chen method for multi component lattice Boltzmann fluids,
  - the P3M and MMM1D methods can now be computed on a GPU,
  - ESPResSo now has a rudimentary Python interface.
  For a complete list of the changes in the release, please refer to:
  http://download.savannah.gnu.org/releases/espressomd/NEWS
* Fri Feb  7 2014 junghans@votca.org
- build openmpi and non-mpi version
* Tue Feb  4 2014 junghans@votca.org
- initial commit
